@@ -3,7 +3,7 @@ import torch
 import numpy as np
 
 from .utils import Dataset
-from labvision.transforms.casnet_cvpr_2018 import casnet_fixation_transform
+from ..transforms.casnet_cvpr_2018 import casnet_fixation_transform
 
 
 def __maxidx__(_list):
